/*****************************************************************************************
*                                                                                        *
* This SAS program will extract the United States Sentencing Commission's fiscal year    *
* 2004 Organizational file and create a SAS dataset.                                     *
*                                                                                        *
* Prior to running the program you must update the DAT file location in the FILNAME line *
* to correspond to the location of the file on your computer, replacing the '.' with the *
* folder path location (e.g. 'C:\temp') .                                                *
*                                                                                        *
* You must also update the library location in the LIBNAME statement to correspond to    *
* the folder you want the output file to be located, replacing the '.' with the folder   *
* path location (e.g. 'C:\temp') .                                                       *
*                                                                                        *
*****************************************************************************************/

/* The following line should contain the complete path and name of your raw data file */
FILENAME datafile '.\corp04nid.dat' ;

/* The following line should contain the directory in which you wish your SAS file to be stored */
libname library '.' ;

/* The following line contains the name (without the extension) for your SAS dataset */
%LET dataset = corp04nid ;

DATA library.&dataset ;
INFILE datafile LRECL=2239;
INPUT
   DISGORGE  1-3            CPIDN  4-7               AMENDYR  8-11         
   BUSTEXT $ 12             OWNSTEXT $ 13            FINSTXT $ 14-50       
   FINDOTXT $ 51            OFENTXT1 $ 52            OFENTXT2 $ 53         
   OFENTXT3 $ 54            PRMONTXT $ 55-154        ORDERTXT $ 155-254    
   REASTXT1 $ 255-318       REASTXT2 $ 319           REASTXT3 $ 320        
   REASTXT4 $ 321           OUTSOURC $ 322           PSR  323              
   JANDC  324               PLEA  325                REASONS  326          
   INDICT  327              SENTRANS  328            WRKSHT  329           
   INCORPYR  330-333        INCORLOC  334            ORGTYPE  335          
   BUSCLAS  336-339         FTEMNUM  340-343         FTEMSIGN  344         
   SELFREP  345             HSMISCND  346            PRCRIME  347          
   PRCIVIL  348             OWNSTRCT  349            FINSTDS  350          
   FINSTDO  351             PRIMOFF  352-353         NOCOUNTS  354-355     
   SOURCES  356             OFFLVL  357-358          DETBFINE  359         
   TOLERNCE  360            HISTORY  361             VIOLATE  362          
   OBSTRUCT  363            COMPLY  364              ACCEPT  365-366       
   CCULPSCO  367-368        FCULPSCO  369-370        MINFINML  371-374     
   MAXFINML  375-377        DISPOSIT  378            PROBATN  379-380      
   COFI  381                PROBMON  382             ORDERCE  383          
   TYPEOTHS  384            CRIMPURP  385            CANTPAY  386          
   DEPSOR  387              REASON1  388-390         REASON2  391          
   REASON3  392             REASON4  393             ADJOFL1  394-395      
   ADJOFL2  396             ADJOFLHI  397-398        ADJ_B1  399-400       
   ADJ_B2  401              ADJ_BHI  402-403         ADJ_C1  404           
   ADJ_C2  405              ADJ_CHI  406             ADJ_D1  407           
   ADJ_D2  408              ADJ_DHI  409             ADJ_E1  410           
   ADJ_E2  411              ADJ_EHI  412             ADJ_F1  413           
   ADJ_F2  414              ADJ_FHI  415             ADJ_G1  416           
   ADJ_G2  417              ADJ_GHI  418             ADJ_H1  419           
   ADJ_H2  420              ADJ_HHI  421             ADJ_I1  422           
   ADJ_I2  423              ADJ_IHI  424             ADJ_J1  425           
   ADJ_J2  426              ADJ_JHI  427             ADJ_K1  428           
   ADJ_K2  429              ADJ_KHI  430             ADJ_L1  431           
   ADJ_L2  432              ADJ_LHI  433             ADJ_M1  434           
   ADJ_M2  435              ADJ_MHI  436             ADJ_N1  437           
   ADJ_N2  438              ADJ_NHI  439             ADJ_O1  440           
   ADJ_O2  441              ADJ_OHI  442             ADJ_P1  443           
   ADJ_P2  444              ADJ_PHI  445             BASADJ1  446-447      
   BASADJ2  448             BASADJHI  449-450        BASE1  451-452        
   BASE2  453               BASEHI  454-455          ADJOFR1  456-457      
   ADJOFR2  458             ADJOFRHI  459-460        ADJR_B1  461-462      
   ADJR_B2  463             ADJR_BHI  464-465        ADJR_C1  466          
   ADJR_C2  467             ADJR_CHI  468            ADJR_D1  469          
   ADJR_D2  470             ADJR_DHI  471            ADJR_E1  472          
   ADJR_E2  473             ADJR_EHI  474            ADJR_F1  475          
   ADJR_F2  476             ADJR_FHI  477            ADJR_G1  478          
   ADJR_G2  479             ADJR_GHI  480            ADJR_H1  481          
   ADJR_H2  482             ADJR_HHI  483            ADJR_I1  484          
   ADJR_I2  485             ADJR_IHI  486            ADJR_J1  487          
   ADJR_J2  488             ADJR_JHI  489            ADJR_K1  490          
   ADJR_K2  491             ADJR_KHI  492            ADJR_L1  493          
   ADJR_L2  494             ADJR_LHI  495            ADJR_M1  496          
   ADJR_M2  497             ADJR_MHI  498            ADJR_N1  499          
   ADJR_N2  500             ADJR_NHI  501            ADJR_O1  502          
   ADJR_O2  503             ADJR_OHI  504            ADJR_P1  505          
   ADJR_P2  506             ADJR_PHI  507            BASADR1  508-509      
   BASADR2  510             BASADRHI  511-512        BASER1  513-514       
   BASER2  515              BASERHI  516-517         ADJOFS1  518-519      
   ADJOFS2  520             ADJOFSHI  521-522        ADJS_B1  523-524      
   ADJS_B2  525             ADJS_BHI  526-527        ADJS_C1  528          
   ADJS_C2  529             ADJS_CHI  530            ADJS_D1  531          
   ADJS_D2  532             ADJS_DHI  533            ADJS_E1  534          
   ADJS_E2  535             ADJS_EHI  536            ADJS_F1  537          
   ADJS_F2  538             ADJS_FHI  539            ADJS_G1  540          
   ADJS_G2  541             ADJS_GHI  542            ADJS_H1  543          
   ADJS_H2  544             ADJS_HHI  545            ADJS_I1  546          
   ADJS_I2  547             ADJS_IHI  548            ADJS_J1  549          
   ADJS_J2  550             ADJS_JHI  551            ADJS_K1  552          
   ADJS_K2  553             ADJS_KHI  554            ADJS_L1  555          
   ADJS_L2  556             ADJS_LHI  557            ADJS_M1  558          
   ADJS_M2  559             ADJS_MHI  560            ADJS_N1  561          
   ADJS_N2  562             ADJS_NHI  563            ADJS_O1  564          
   ADJS_O2  565             ADJS_OHI  566            ADJS_P1  567          
   ADJS_P2  568             ADJS_PHI  569            BASADS1  570          
   BASADS2  571             BASADSHI  572            BASES1  573-574       
   BASES2  575              BASESHI  576-577         ADJOFC1  578-579      
   ADJOFC2  580             ADJOFCHI  581-582        ADJC_B1  583-584      
   ADJC_B2  585             ADJC_BHI  586-587        ADJC_C1  588          
   ADJC_C2  589             ADJC_CHI  590            ADJC_D1  591          
   ADJC_D2  592             ADJC_DHI  593            ADJC_E1  594          
   ADJC_E2  595             ADJC_EHI  596            ADJC_F1  597          
   ADJC_F2  598             ADJC_FHI  599            ADJC_G1  600          
   ADJC_G2  601             ADJC_GHI  602            ADJC_H1  603          
   ADJC_H2  604             ADJC_HHI  605            ADJC_I1  606          
   ADJC_I2  607             ADJC_IHI  608            ADJC_J1  609          
   ADJC_J2  610             ADJC_JHI  611            ADJC_K1  612          
   ADJC_K2  613             ADJC_KHI  614            ADJC_L1  615          
   ADJC_L2  616             ADJC_LHI  617            ADJC_M1  618          
   ADJC_M2  619             ADJC_MHI  620            ADJC_N1  621          
   ADJC_N2  622             ADJC_NHI  623            ADJC_O1  624          
   ADJC_O2  625             ADJC_OHI  626            ADJC_P1  627          
   ADJC_P2  628             ADJC_PHI  629            BASADC1  630          
   BASADC2  631             BASADCHI  632            BASEC1  633           
   BASEC2  634              BASECHI  635             ADJL_B1 $ 636         
   ADJL_B2 $ 637            ADJL_BHI $ 638           ADJL_C1 $ 639         
   ADJL_C2 $ 640            ADJL_CHI $ 641           ADJL_D1 $ 642         
   ADJL_D2 $ 643            ADJL_DHI $ 644           ADJL_E1 $ 645         
   ADJL_E2 $ 646            ADJL_EHI $ 647           ADJL_F1 $ 648         
   ADJL_F2 $ 649            ADJL_FHI $ 650           ADJL_G1 $ 651         
   ADJL_G2 $ 652            ADJL_GHI $ 653           ADJL_H1 $ 654         
   ADJL_H2 $ 655            ADJL_HHI $ 656           ADJL_I1 $ 657         
   ADJL_I2 $ 658            ADJL_IHI $ 659           ADJL_J1 $ 660         
   ADJL_J2 $ 661            ADJL_JHI $ 662           ADJL_K1 $ 663         
   ADJL_K2 $ 664            ADJL_KHI $ 665           ADJL_L1 $ 666         
   ADJL_L2 $ 667            ADJL_LHI $ 668           ADJL_M1 $ 669         
   ADJL_M2 $ 670            ADJL_MHI $ 671           ADJL_N1 $ 672         
   ADJL_N2 $ 673            ADJL_NHI $ 674           ADJL_O1 $ 675         
   ADJL_O2 $ 676            ADJL_OHI $ 677           ADJL_P1 $ 678         
   ADJL_P2 $ 679            ADJL_PHI $ 680           BASEL1 $ 681          
   BASEL2 $ 682             BASELHI $ 683            ADRL_B1 $ 684         
   ADRL_B2 $ 685            ADRL_BHI $ 686           ADRL_C1 $ 687         
   ADRL_C2 $ 688            ADRL_CHI $ 689           ADRL_D1 $ 690         
   ADRL_D2 $ 691            ADRL_DHI $ 692           ADRL_E1 $ 693         
   ADRL_E2 $ 694            ADRL_EHI $ 695           ADRL_F1 $ 696         
   ADRL_F2 $ 697            ADRL_FHI $ 698           ADRL_G1 $ 699         
   ADRL_G2 $ 700            ADRL_GHI $ 701           ADRL_H1 $ 702         
   ADRL_H2 $ 703            ADRL_HHI $ 704           ADRL_I1 $ 705         
   ADRL_I2 $ 706            ADRL_IHI $ 707           ADRL_J1 $ 708         
   ADRL_J2 $ 709            ADRL_JHI $ 710           ADRL_K1 $ 711         
   ADRL_K2 $ 712            ADRL_KHI $ 713           ADRL_L1 $ 714         
   ADRL_L2 $ 715            ADRL_LHI $ 716           ADRL_M1 $ 717         
   ADRL_M2 $ 718            ADRL_MHI $ 719           ADRL_N1 $ 720         
   ADRL_N2 $ 721            ADRL_NHI $ 722           ADRL_O1 $ 723         
   ADRL_O2 $ 724            ADRL_OHI $ 725           ADRL_P1 $ 726         
   ADRL_P2 $ 727            ADRL_PHI $ 728           BASERL1 $ 729         
   BASERL2 $ 730            BASERLHI $ 731           ADSL_B1 $ 732         
   ADSL_B2 $ 733            ADSL_BHI $ 734           ADSL_C1 $ 735         
   ADSL_C2 $ 736            ADSL_CHI $ 737           ADSL_D1 $ 738         
   ADSL_D2 $ 739            ADSL_DHI $ 740           ADSL_E1 $ 741         
   ADSL_E2 $ 742            ADSL_EHI $ 743           ADSL_F1 $ 744         
   ADSL_F2 $ 745            ADSL_FHI $ 746           ADSL_G1 $ 747         
   ADSL_G2 $ 748            ADSL_GHI $ 749           ADSL_H1 $ 750         
   ADSL_H2 $ 751            ADSL_HHI $ 752           ADSL_I1 $ 753         
   ADSL_I2 $ 754            ADSL_IHI $ 755           ADSL_J1 $ 756         
   ADSL_J2 $ 757            ADSL_JHI $ 758           ADSL_K1 $ 759         
   ADSL_K2 $ 760            ADSL_KHI $ 761           ADSL_L1 $ 762         
   ADSL_L2 $ 763            ADSL_LHI $ 764           ADSL_M1 $ 765         
   ADSL_M2 $ 766            ADSL_MHI $ 767           ADSL_N1 $ 768         
   ADSL_N2 $ 769            ADSL_NHI $ 770           ADSL_O1 $ 771         
   ADSL_O2 $ 772            ADSL_OHI $ 773           ADSL_P1 $ 774         
   ADSL_P2 $ 775            ADSL_PHI $ 776           BASESL1 $ 777         
   BASESL2 $ 778            BASESLHI $ 779           ADCL_B1 $ 780         
   ADCL_B2 $ 781            ADCL_BHI $ 782           ADCL_C1 $ 783         
   ADCL_C2 $ 784            ADCL_CHI $ 785           ADCL_D1 $ 786         
   ADCL_D2 $ 787            ADCL_DHI $ 788           ADCL_E1 $ 789         
   ADCL_E2 $ 790            ADCL_EHI $ 791           ADCL_F1 $ 792         
   ADCL_F2 $ 793            ADCL_FHI $ 794           ADCL_G1 $ 795         
   ADCL_G2 $ 796            ADCL_GHI $ 797           ADCL_H1 $ 798         
   ADCL_H2 $ 799            ADCL_HHI $ 800           ADCL_I1 $ 801         
   ADCL_I2 $ 802            ADCL_IHI $ 803           ADCL_J1 $ 804         
   ADCL_J2 $ 805            ADCL_JHI $ 806           ADCL_K1 $ 807         
   ADCL_K2 $ 808            ADCL_KHI $ 809           ADCL_L1 $ 810         
   ADCL_L2 $ 811            ADCL_LHI $ 812           ADCL_M1 $ 813         
   ADCL_M2 $ 814            ADCL_MHI $ 815           ADCL_N1 $ 816         
   ADCL_N2 $ 817            ADCL_NHI $ 818           ADCL_O1 $ 819         
   ADCL_O2 $ 820            ADCL_OHI $ 821           ADCL_P1 $ 822         
   ADCL_P2 $ 823            ADCL_PHI $ 824           BASECL1 $ 825         
   BASECL2 $ 826-828        BASECLHI $ 829           GDLINE1 $ 830-834     
   GDLINE2 $ 835-839        GDSTAT1 $ 840-844        GDSTAT2 $ 845-849     
   GDREF1 $ 850-854         GDREF2 $ 855             GDCROS1 $ 856-860     
   GDCROS2 $ 861            NOCOMP  862              GDLINEHI $ 863-867    
   GDSTATHI $ 868-872       GDREFHI $ 873-877        GDCROSHI $ 878-882    
   SMIN1  883-886           SMIN2  887               SMIN3  888            
   SMIN4  889               SMIN5  890               SMIN6  891            
   SMIN7  892               SMIN8  893               SMIN9  894            
   SMIN10  895              SMIN11  896              SMIN12  897           
   SMIN13  898              SMIN14  899              SMIN15  900           
   SMIN16  901              SMIN17  902              SMIN18  903           
   SMIN19  904              SMIN20  905              SMIN21  906           
   SMIN22  907              SMIN23  908              SMIN24  909           
   SMIN25  910              SMIN26  911              SMIN27  912           
   SMIN28  913              SMIN29  914              SMIN30  915           
   SMIN31  916              SMIN32  917              SMIN33  918           
   SMIN34  919              SMIN35  920              SMIN36  921           
   SMIN37  922              SMIN38  923              SMIN39  924           
   SMIN40  925              SMIN41  926              SMIN42  927           
   SMIN43  928              SMIN44  929              SMIN45  930           
   SMIN46  931              SMIN47  932              SMIN48  933           
   SMIN49  934              SMIN50  935              SMAX1  936-943        
   SMAX2  944-951           SMAX3  952-958           SMAX4  959-965        
   SMAX5  966-971           SMAX6  972-977           SMAX7  978-983        
   SMAX8  984-989           SMAX9  990-995           SMAX10  996-1001      
   SMAX11  1002-1007        SMAX12  1008-1013        SMAX13  1014-1019     
   SMAX14  1020-1025        SMAX15  1026-1031        SMAX16  1032-1037     
   SMAX17  1038-1043        SMAX18  1044-1049        SMAX19  1050-1055     
   SMAX20  1056-1061        SMAX21  1062-1067        SMAX22  1068-1073     
   SMAX23  1074-1079        SMAX24  1080-1085        SMAX25  1086-1091     
   SMAX26  1092-1097        SMAX27  1098-1103        SMAX28  1104-1109     
   SMAX29  1110-1115        SMAX30  1116-1121        SMAX31  1122-1127     
   SMAX32  1128-1133        SMAX33  1134-1139        SMAX34  1140-1145     
   SMAX35  1146-1151        SMAX36  1152-1157        SMAX37  1158-1163     
   SMAX38  1164-1169        SMAX39  1170-1175        SMAX40  1176-1181     
   SMAX41  1182-1187        SMAX42  1188-1193        SMAX43  1194-1199     
   SMAX44  1200-1205        SMAX45  1206-1211        SMAX46  1212-1217     
   SMAX47  1218-1223        SMAX48  1224-1229        SMAX49  1230-1235     
   SMAX50  1236-1241        STA1_1 $ 1242-1250       STA1_2 $ 1251-1259    
   STA1_3 $ 1260-1268       STA1_4 $ 1269-1277       STA1_5 $ 1278-1286    
   STA1_6 $ 1287-1295       STA1_7 $ 1296-1304       STA1_8 $ 1305-1313    
   STA1_9 $ 1314-1322       STA1_10 $ 1323-1332      STA1_11 $ 1333-1342   
   STA1_12 $ 1343-1352      STA1_13 $ 1353-1362      STA1_14 $ 1363-1371   
   STA1_15 $ 1372-1379      STA1_16 $ 1380-1387      STA1_17 $ 1388-1395   
   STA1_18 $ 1396-1403      STA1_19 $ 1404-1411      STA1_20 $ 1412-1419   
   STA1_21 $ 1420-1427      STA1_22 $ 1428-1435      STA1_23 $ 1436-1443   
   STA1_24 $ 1444-1451      STA1_25 $ 1452-1459      STA1_26 $ 1460-1467   
   STA1_27 $ 1468-1475      STA1_28 $ 1476-1483      STA1_29 $ 1484-1491   
   STA1_30 $ 1492-1499      STA1_31 $ 1500-1507      STA1_32 $ 1508-1515   
   STA1_33 $ 1516-1523      STA1_34 $ 1524-1531      STA1_35 $ 1532-1538   
   STA1_36 $ 1539-1545      STA1_37 $ 1546-1552      STA1_38 $ 1553-1559   
   STA1_39 $ 1560-1566      STA1_40 $ 1567-1573      STA1_41 $ 1574-1580   
   STA1_42 $ 1581-1587      STA1_43 $ 1588-1594      STA1_44 $ 1595-1600   
   STA1_45 $ 1601-1606      STA1_46 $ 1607-1612      STA1_47 $ 1613-1618   
   STA1_48 $ 1619-1624      STA1_49 $ 1625-1630      STA1_50 $ 1631-1636   
   STA2_1 $ 1637-1645       STA2_2 $ 1646-1654       STA2_3 $ 1655-1662    
   STA2_4 $ 1663-1669       STA2_5 $ 1670-1677       STA2_6 $ 1678-1685    
   STA2_7 $ 1686-1692       STA2_8 $ 1693-1700       STA2_9 $ 1701-1707    
   STA2_10 $ 1708-1714      STA2_11 $ 1715-1722      STA2_12 $ 1723-1729   
   STA2_13 $ 1730-1737      STA2_14 $ 1738-1745      STA2_15 $ 1746-1752   
   STA2_16 $ 1753-1759      STA2_17 $ 1760-1766      STA2_18 $ 1767-1773   
   STA2_19 $ 1774-1780      STA2_20 $ 1781-1787      STA2_21 $ 1788-1794   
   STA2_22 $ 1795-1801      STA2_23 $ 1802-1808      STA2_24 $ 1809-1815   
   STA2_25 $ 1816-1822      STA2_26 $ 1823-1829      STA2_27 $ 1830-1836   
   STA2_28 $ 1837-1843      STA2_29 $ 1844-1850      STA2_30 $ 1851-1857   
   STA2_31 $ 1858-1864      STA2_32 $ 1865-1871      STA2_33 $ 1872-1878   
   STA2_34 $ 1879-1885      STA2_35 $ 1886-1891      STA2_36 $ 1892-1897   
   STA2_37 $ 1898-1903      STA2_38 $ 1904-1909      STA2_39 $ 1910-1915   
   STA2_40 $ 1916-1921      STA2_41 $ 1922-1927      STA2_42 $ 1928-1933   
   STA2_43 $ 1934-1939      STA2_44 $ 1940           STA2_45 $ 1941        
   STA2_46 $ 1942           STA2_47 $ 1943           STA2_48 $ 1944        
   STA2_49 $ 1945           STA2_50 $ 1946-1951      STA3_1 $ 1952-1960    
   STA3_2 $ 1961-1968       STA3_3 $ 1969-1974       STA3_4 $ 1975-1982    
   STA3_5 $ 1983-1988       STA3_6 $ 1989-1994       STA3_7 $ 1995-2002    
   STA3_8 $ 2003-2008       STA3_9 $ 2009-2016       STA3_10 $ 2017-2024   
   STA3_11 $ 2025-2030      STA3_12 $ 2031-2038      STA3_13 $ 2039-2044   
   STA3_14 $ 2045-2050      STA3_15 $ 2051-2058      STA3_16 $ 2059        
   STA3_17 $ 2060           STA3_18 $ 2061           STA3_19 $ 2062        
   STA3_20 $ 2063           STA3_21 $ 2064           STA3_22 $ 2065        
   STA3_23 $ 2066           STA3_24 $ 2067           STA3_25 $ 2068        
   STA3_26 $ 2069           STA3_27 $ 2070           STA3_28 $ 2071        
   STA3_29 $ 2072           STA3_30 $ 2073           STA3_31 $ 2074        
   STA3_32 $ 2075           STA3_33 $ 2076           STA3_34 $ 2077        
   STA3_35 $ 2078           STA3_36 $ 2079           STA3_37 $ 2080        
   STA3_38 $ 2081           STA3_39 $ 2082           STA3_40 $ 2083        
   STA3_41 $ 2084           STA3_42 $ 2085           STA3_43 $ 2086        
   STA3_44 $ 2087           STA3_45 $ 2088           STA3_46 $ 2089        
   STA3_47 $ 2090           STA3_48 $ 2091           STA3_49 $ 2092        
   STA3_50 $ 2093-2098      NWSTAT1 $ 2099-2107      NWSTAT2 $ 2108-2117   
   NWSTAT3 $ 2118-2127      NWSTAT4 $ 2128-2135      NWSTAT5 $ 2136-2144   
   NWSTAT6 $ 2145-2150      NWSTAT7 $ 2151-2156      NWSTAT8 $ 2157-2163   
   NOUSTAT  2164            BASEFINE  2165-2173      CH2APP  2174          
   CH8FINGD  2175           CMSRVORD  2176           COMPLYPR  2177        
   COSTASSM  2178           FINOFFST  2179-2183      FORFEITR  2184-2190   
   GLFINMAX  2191-2199      GLFINMIN  2200-2208      OFFENSE1  2209-2210   
   OFFENSE2  2211-2212      OFFENSE3  2213           REMEDORD  2214        
   VICTNOTE  2215           BLAKPOST  2216           SENTYR  2217-2220     
   QUARTER  2221            TYPEOTTX $ 2222          NEWCNVTN  2223        
   NOREAS  2224             RESTCAT  2225            FINECAT  2226         
   SUSFNCAT  2227           LCAT1  2228              LCAT2  2229           
   LCATHI  2230             LCATS1  2231             LCATS2  2232          
   LCATSHI  2233            LCATR1  2234             LCATR2  2235          
   LCATRHI  2236            LCATC1  2237             LCATC2  2238          
   LCATCHI  2239          ;                       

LENGTH
   DISGORGE 4               CPIDN 4                  AMENDYR 4             
   PSR 3                    JANDC 3                  PLEA 3                
   REASONS 3                INDICT 3                 SENTRANS 3            
   WRKSHT 3                 INCORPYR 4               INCORLOC 3            
   ORGTYPE 3                BUSCLAS 4                FTEMNUM 4             
   FTEMSIGN 3               SELFREP 3                HSMISCND 3            
   PRCRIME 3                PRCIVIL 3                OWNSTRCT 3            
   FINSTDS 3                FINSTDO 3                PRIMOFF 3             
   NOCOUNTS 3               SOURCES 3                OFFLVL 3              
   DETBFINE 3               TOLERNCE 3               HISTORY 3             
   VIOLATE 3                OBSTRUCT 3               COMPLY 3              
   ACCEPT 3                 CCULPSCO 3               FCULPSCO 3            
   DISPOSIT 3               PROBATN 3                COFI 3                
   PROBMON 3                ORDERCE 3                TYPEOTHS 3            
   CRIMPURP 3               CANTPAY 3                DEPSOR 3              
   REASON1 4                REASON2 3                REASON3 3             
   REASON4 3                ADJOFL1 3                ADJOFL2 3             
   ADJOFLHI 3               ADJ_B1 3                 ADJ_B2 3              
   ADJ_BHI 3                ADJ_C1 3                 ADJ_C2 3              
   ADJ_CHI 3                ADJ_D1 3                 ADJ_D2 3              
   ADJ_DHI 3                ADJ_E1 3                 ADJ_E2 3              
   ADJ_EHI 3                ADJ_F1 3                 ADJ_F2 3              
   ADJ_FHI 3                ADJ_G1 3                 ADJ_G2 3              
   ADJ_GHI 3                ADJ_H1 3                 ADJ_H2 3              
   ADJ_HHI 3                ADJ_I1 3                 ADJ_I2 3              
   ADJ_IHI 3                ADJ_J1 3                 ADJ_J2 3              
   ADJ_JHI 3                ADJ_K1 3                 ADJ_K2 3              
   ADJ_KHI 3                ADJ_L1 3                 ADJ_L2 3              
   ADJ_LHI 3                ADJ_M1 3                 ADJ_M2 3              
   ADJ_MHI 3                ADJ_N1 3                 ADJ_N2 3              
   ADJ_NHI 3                ADJ_O1 3                 ADJ_O2 3              
   ADJ_OHI 3                ADJ_P1 3                 ADJ_P2 3              
   ADJ_PHI 3                BASADJ1 3                BASADJ2 3             
   BASADJHI 3               BASE1 3                  BASE2 3               
   BASEHI 3                 ADJOFR1 3                ADJOFR2 3             
   ADJOFRHI 3               ADJR_B1 3                ADJR_B2 3             
   ADJR_BHI 3               ADJR_C1 3                ADJR_C2 3             
   ADJR_CHI 3               ADJR_D1 3                ADJR_D2 3             
   ADJR_DHI 3               ADJR_E1 3                ADJR_E2 3             
   ADJR_EHI 3               ADJR_F1 3                ADJR_F2 3             
   ADJR_FHI 3               ADJR_G1 3                ADJR_G2 3             
   ADJR_GHI 3               ADJR_H1 3                ADJR_H2 3             
   ADJR_HHI 3               ADJR_I1 3                ADJR_I2 3             
   ADJR_IHI 3               ADJR_J1 3                ADJR_J2 3             
   ADJR_JHI 3               ADJR_K1 3                ADJR_K2 3             
   ADJR_KHI 3               ADJR_L1 3                ADJR_L2 3             
   ADJR_LHI 3               ADJR_M1 3                ADJR_M2 3             
   ADJR_MHI 3               ADJR_N1 3                ADJR_N2 3             
   ADJR_NHI 3               ADJR_O1 3                ADJR_O2 3             
   ADJR_OHI 3               ADJR_P1 3                ADJR_P2 3             
   ADJR_PHI 3               BASADR1 3                BASADR2 3             
   BASADRHI 3               BASER1 3                 BASER2 3              
   BASERHI 3                ADJOFS1 3                ADJOFS2 3             
   ADJOFSHI 3               ADJS_B1 3                ADJS_B2 3             
   ADJS_BHI 3               ADJS_C1 3                ADJS_C2 3             
   ADJS_CHI 3               ADJS_D1 3                ADJS_D2 3             
   ADJS_DHI 3               ADJS_E1 3                ADJS_E2 3             
   ADJS_EHI 3               ADJS_F1 3                ADJS_F2 3             
   ADJS_FHI 3               ADJS_G1 3                ADJS_G2 3             
   ADJS_GHI 3               ADJS_H1 3                ADJS_H2 3             
   ADJS_HHI 3               ADJS_I1 3                ADJS_I2 3             
   ADJS_IHI 3               ADJS_J1 3                ADJS_J2 3             
   ADJS_JHI 3               ADJS_K1 3                ADJS_K2 3             
   ADJS_KHI 3               ADJS_L1 3                ADJS_L2 3             
   ADJS_LHI 3               ADJS_M1 3                ADJS_M2 3             
   ADJS_MHI 3               ADJS_N1 3                ADJS_N2 3             
   ADJS_NHI 3               ADJS_O1 3                ADJS_O2 3             
   ADJS_OHI 3               ADJS_P1 3                ADJS_P2 3             
   ADJS_PHI 3               BASADS1 3                BASADS2 3             
   BASADSHI 3               BASES1 3                 BASES2 3              
   BASESHI 3                ADJOFC1 3                ADJOFC2 3             
   ADJOFCHI 3               ADJC_B1 3                ADJC_B2 3             
   ADJC_BHI 3               ADJC_C1 3                ADJC_C2 3             
   ADJC_CHI 3               ADJC_D1 3                ADJC_D2 3             
   ADJC_DHI 3               ADJC_E1 3                ADJC_E2 3             
   ADJC_EHI 3               ADJC_F1 3                ADJC_F2 3             
   ADJC_FHI 3               ADJC_G1 3                ADJC_G2 3             
   ADJC_GHI 3               ADJC_H1 3                ADJC_H2 3             
   ADJC_HHI 3               ADJC_I1 3                ADJC_I2 3             
   ADJC_IHI 3               ADJC_J1 3                ADJC_J2 3             
   ADJC_JHI 3               ADJC_K1 3                ADJC_K2 3             
   ADJC_KHI 3               ADJC_L1 3                ADJC_L2 3             
   ADJC_LHI 3               ADJC_M1 3                ADJC_M2 3             
   ADJC_MHI 3               ADJC_N1 3                ADJC_N2 3             
   ADJC_NHI 3               ADJC_O1 3                ADJC_O2 3             
   ADJC_OHI 3               ADJC_P1 3                ADJC_P2 3             
   ADJC_PHI 3               BASADC1 3                BASADC2 3             
   BASADCHI 3               BASEC1 3                 BASEC2 3              
   BASECHI 3                NOCOMP 3                 SMIN1 4               
   SMIN2 3                  SMIN3 3                  SMIN4 3               
   SMIN5 3                  SMIN6 3                  SMIN7 3               
   SMIN8 3                  SMIN9 3                  SMIN10 3              
   SMIN11 3                 SMIN12 3                 SMIN13 3              
   SMIN14 3                 SMIN15 3                 SMIN16 3              
   SMIN17 3                 SMIN18 3                 SMIN19 3              
   SMIN20 3                 SMIN21 3                 SMIN22 3              
   SMIN23 3                 SMIN24 3                 SMIN25 3              
   SMIN26 3                 SMIN27 3                 SMIN28 3              
   SMIN29 3                 SMIN30 3                 SMIN31 3              
   SMIN32 3                 SMIN33 3                 SMIN34 3              
   SMIN35 3                 SMIN36 3                 SMIN37 3              
   SMIN38 3                 SMIN39 3                 SMIN40 3              
   SMIN41 3                 SMIN42 3                 SMIN43 3              
   SMIN44 3                 SMIN45 3                 SMIN46 3              
   SMIN47 3                 SMIN48 3                 SMIN49 3              
   SMIN50 3                 SMAX1 6                  SMAX2 6               
   SMAX3 6                  SMAX4 6                  SMAX5 6               
   SMAX6 6                  SMAX7 6                  SMAX8 6               
   SMAX9 6                  SMAX10 6                 SMAX11 6              
   SMAX12 6                 SMAX13 6                 SMAX14 6              
   SMAX15 6                 SMAX16 6                 SMAX17 6              
   SMAX18 6                 SMAX19 6                 SMAX20 6              
   SMAX21 6                 SMAX22 6                 SMAX23 6              
   SMAX24 6                 SMAX25 6                 SMAX26 6              
   SMAX27 6                 SMAX28 6                 SMAX29 6              
   SMAX30 6                 SMAX31 6                 SMAX32 6              
   SMAX33 6                 SMAX34 6                 SMAX35 6              
   SMAX36 6                 SMAX37 6                 SMAX38 6              
   SMAX39 6                 SMAX40 6                 SMAX41 6              
   SMAX42 6                 SMAX43 6                 SMAX44 6              
   SMAX45 6                 SMAX46 6                 SMAX47 6              
   SMAX48 6                 SMAX49 6                 SMAX50 6              
   NOUSTAT 3                BASEFINE 6               CH2APP 3              
   CH8FINGD 3               CMSRVORD 3               COMPLYPR 3            
   COSTASSM 3               FINOFFST 6               FORFEITR 6            
   GLFINMAX 6               GLFINMIN 6               OFFENSE1 3            
   OFFENSE2 3               OFFENSE3 3               REMEDORD 3            
   VICTNOTE 3               BLAKPOST 3               SENTYR 4              
   QUARTER 3                NEWCNVTN 3               NOREAS 3              
   RESTCAT 3                FINECAT 3                SUSFNCAT 3            
   LCAT1 3                  LCAT2 3                  LCATHI 3              
   LCATS1 3                 LCATS2 3                 LCATSHI 3             
   LCATR1 3                 LCATR2 3                 LCATRHI 3             
   LCATC1 3                 LCATC2 3                 LCATCHI 3 ;

         

RUN ;
